pub type Color = GenericColor<Percentage>;Expand description
A computed value for <color>.
Aliased Type
#[repr(C)]pub enum Color {
Absolute(AbsoluteColor),
ColorFunction(Box<ColorFunction<GenericColor<Percentage>>>),
CurrentColor,
ColorMix(Box<GenericColorMix<GenericColor<Percentage>, Percentage>>),
ContrastColor(Box<GenericColor<Percentage>>),
}Variants
Absolute(AbsoluteColor)
The actual numeric color.
ColorFunction(Box<ColorFunction<GenericColor<Percentage>>>)
A unresolvable color.
CurrentColor
The CurrentColor keyword.
ColorMix(Box<GenericColorMix<GenericColor<Percentage>, Percentage>>)
The color-mix() function.
ContrastColor(Box<GenericColor<Percentage>>)
The contrast-color() function.
Implementations
Sourceimpl Color
impl Color
Sourcepub const TRANSPARENT_BLACK: Self
pub const TRANSPARENT_BLACK: Self
A fully transparent color.
Sourcepub fn from_color_mix(color_mix: ColorMix) -> Self
pub fn from_color_mix(color_mix: ColorMix) -> Self
Create a new computed Color from a given color-mix, simplifying it to an absolute color
if possible.
Sourcepub fn resolve_to_absolute(
&self,
current_color: &AbsoluteColor,
) -> AbsoluteColor
pub fn resolve_to_absolute( &self, current_color: &AbsoluteColor, ) -> AbsoluteColor
Combine this complex color with the given foreground color into an absolute color.
fn contrast_ratio(a: &AbsoluteColor, b: &AbsoluteColor) -> f32